==> RsFsw-5.20.1.tar.gz: RsFsw-5.20.1/RsFsw/Implementations/Applications/K70_Vsa/InputPy/Dpath.py <==
from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DpathCls:
	"""Dpath commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dpath", core, parent)

	def set(self, auto_off: enums.State, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<ip>:DPATh \n
		Snippet: driver.applications.k70Vsa.inputPy.dpath.set(auto_off = enums.State.ALL, inputIx = repcap.InputIx.Default) \n
		Enables or disables the use of the direct path for frequencies close to 0 Hz. If an external frontend is active, the
		direct path is always used. \n
			:param auto_off: No help available
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.enum_scalar_to_str(auto_off, enums.State)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:DPATh {param}')

	# noinspection PyTypeChecker
	def get(self, inputIx=repcap.InputIx.Default) -> enums.State:
		"""SCPI: INPut<ip>:DPATh \n
		Snippet: value: enums.State = driver.applications.k70Vsa.inputPy.dpath.get(inputIx = repcap.InputIx.Default) \n
		Enables or disables the use of the direct path for frequencies close to 0 Hz. If an external frontend is active, the
		direct path is always used. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: auto_off: No help available"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:DPATh?')
		return Conversions.str_to_scalar_enum(response, enums.State)

==> RsFsw-6.0.0.tar.gz: RsFsw-6.0.0/RsFsw/Implementations/Applications/K70_Vsa/InputPy/Dpath.py <==
from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DpathCls:
	"""Dpath commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dpath", core, parent)

	def set(self, auto_off: enums.State) -> None:
		"""SCPI: INPut:DPATh \n
		Snippet: driver.applications.k70Vsa.inputPy.dpath.set(auto_off = enums.State.ALL) \n
		Enables or disables the use of the direct path for frequencies close to 0 Hz. If an external frontend is active, the
		direct path is always used. \n
			:param auto_off: AUTO | OFF AUTO | 1 (Default) the direct path is used automatically for frequencies close to 0 Hz. OFF | 0 The analog mixer path is always used.
		"""
		param = Conversions.enum_scalar_to_str(auto_off, enums.State)
		self._core.io.write(f'INPut:DPATh {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.State:
		"""SCPI: INPut:DPATh \n
		Snippet: value: enums.State = driver.applications.k70Vsa.inputPy.dpath.get() \n
		Enables or disables the use of the direct path for frequencies close to 0 Hz. If an external frontend is active, the
		direct path is always used. \n
			:return: auto_off: No help available"""
		response = self._core.io.query_str(f'INPut:DPATh?')
		return Conversions.str_to_scalar_enum(response, enums.State)
